# CHANGELOG



## v0.0.0 (2023-06-22)

### Feat

* FEAT: add keep-going: true and cluster-cancel: &#34;scancel&#34; to profile ([`a9e8056`](https://github.com/phim/sravel/snakecdysis/commit/a9e80565f7e84015c00fab91041fe80434d1f3ce))

### Fix

* FIX: test methode to capture partition if not default with star ([`fa299ec`](https://github.com/phim/sravel/snakecdysis/commit/fa299ec3d389252d47684ecce4ccbf0be3739517))

* FIX: Edit tools ([`711731e`](https://github.com/phim/sravel/snakecdysis/commit/711731ed71b8852f7652b8d9fcc6be1efedadef1))

* FIX: unpack dicotool ([`706d011`](https://github.com/phim/sravel/snakecdysis/commit/706d011699190605fffffe19d52e10267786a24e))

* FIX: Edit tools rewrite ([`8b1ec80`](https://github.com/phim/sravel/snakecdysis/commit/8b1ec80efec36eee228c0e54d339edc54cefcd5c))

* FIX: rename logo in lower ([`f705a7c`](https://github.com/phim/sravel/snakecdysis/commit/f705a7cd5b7dca77e1703386ee43b2519fc18570))

* FIX: template exemple ([`4a710cb`](https://github.com/phim/sravel/snakecdysis/commit/4a710cb859fb84c8467201a67fa69f106db19068))

* FIX: doesn&#39;t apply lower for package name ([`3b96b3d`](https://github.com/phim/sravel/snakecdysis/commit/3b96b3d056c7b93327899abb75d2ea8a5a92b23a))

* FIX: write singularity path ([`44721d0`](https://github.com/phim/sravel/snakecdysis/commit/44721d00eeebce0315c52096c7f69187cb7bc4e7))

* FIX: singularity path not update see (Issue #1)

update edit_tools to always use user_tool_path and fix replace INSTALL_PATH on snake_wrapper.py ([`334ad45`](https://github.com/phim/sravel/snakecdysis/commit/334ad45f71c50487ebc8227bc0ff6e90a2a663c2))

* FIX: bad rename of variable DOCS ([`9f83cc1`](https://github.com/phim/sravel/snakecdysis/commit/9f83cc1fb2d4bffe068849d7d9c68d4832a6f5a8))

### Perf

* PERF: switch setup.py to pyproject.toml

according to packaging docs I use pyproject.toml with setuptools backend ([`bd86f7b`](https://github.com/phim/sravel/snakecdysis/commit/bd86f7bba6ceafe2470e93447416f6499d2b649a))

### Unknown

* fix: remove __pycache__ directory from template ([`dd89f5f`](https://github.com/phim/sravel/snakecdysis/commit/dd89f5f61577c798ee619ff53a240fc2e9c4d1e5))

* remove todo ([`052a0a5`](https://github.com/phim/sravel/snakecdysis/commit/052a0a5b2fbd191b6cb2616ae0a5f71d8322fdaf))

* update version ([`299fd71`](https://github.com/phim/sravel/snakecdysis/commit/299fd71e6c64cdc5d0a5806e3fa93917d45f4e8f))

* Merge branch &#39;3-only-singularity-in&#39; into &#39;main&#39;

fix: git_cluster_config path

Closes #3

See merge request phim/sravel/snakecdysis!2 ([`9b8da9c`](https://github.com/phim/sravel/snakecdysis/commit/9b8da9cd4af60cd471d55a43745b3cb4f48acb13))

* fix: remove cluster-cancel cause fail on run

remove coockiescutter cluster-cancel default ([`43247a4`](https://github.com/phim/sravel/snakecdysis/commit/43247a42d8186b0958956a8585822a06a78ad7d3))

* fix: git_cluster_config path

replace git_cluster_config path from default_profile to install_path ([`65ff14f`](https://github.com/phim/sravel/snakecdysis/commit/65ff14fcda40fad318e6df32ce0e9c9994888dda))

* fix: fix issue #3-only-singularity-in ([`8f594f0`](https://github.com/phim/sravel/snakecdysis/commit/8f594f0d41b5b720605e63f5c1558633b4632f14))

* fix readthedocs link to gitlab ([`798e957`](https://github.com/phim/sravel/snakecdysis/commit/798e9571afaf0da8f680efe74ba639158c1ccb5a))

* fix image link ([`a22a170`](https://github.com/phim/sravel/snakecdysis/commit/a22a1701ebf4c7d9a4bb238440785e2b415ca6e4))

* Merge remote-tracking branch &#39;origin/main&#39; into main ([`8fe62a5`](https://github.com/phim/sravel/snakecdysis/commit/8fe62a5efb6ee0e152f52b8bd88ff2dd193af601))

* fix: add setuptools_scm requirement ([`036e1a8`](https://github.com/phim/sravel/snakecdysis/commit/036e1a8ce5df9490bc05a515cb2fc4cdc7719fba))

* fix: add setuptools_scm requirement ([`3c3a403`](https://github.com/phim/sravel/snakecdysis/commit/3c3a4037d094761f7ea7740e3c9dcfc3732fe7b3))

* fix: remove setuptools_scm to VERSION file ([`b0c5d8e`](https://github.com/phim/sravel/snakecdysis/commit/b0c5d8ed133963a7923e880bb0bb5d35fff717d2))

*  add VERSION ([`0d80540`](https://github.com/phim/sravel/snakecdysis/commit/0d80540c1fd25030b2430e9248c9dc3c7b1fa707))

* fix: add setuptools_scm requirement ([`ce0fa43`](https://github.com/phim/sravel/snakecdysis/commit/ce0fa4363396373bab8d1a39d1bfcc9909a67edb))

* use setuptools_scm instead of hard file ([`c93db8c`](https://github.com/phim/sravel/snakecdysis/commit/c93db8ce79ccbcfec424ee81627331aa450e32a7))

* DOC: update ([`20260b0`](https://github.com/phim/sravel/snakecdysis/commit/20260b0aeabccbd64ef14f82111a691630e6a32e))

* DOC: update url image and python version ([`505936d`](https://github.com/phim/sravel/snakecdysis/commit/505936dc5faa6ba3b79b355ae1aee9b4c24c5b89))

* perf: remove setup.py to use pyproject.toml ([`abd0502`](https://github.com/phim/sravel/snakecdysis/commit/abd05023bbf101114bccebd9abd9b96a1f16edd6))

* DOC: add exemple to template ([`8b3c785`](https://github.com/phim/sravel/snakecdysis/commit/8b3c7854bb65921d9e33e1da86363fe33ef5901f))

* DOC: update config to use toml ([`2b767ea`](https://github.com/phim/sravel/snakecdysis/commit/2b767ea73bc89fcaf0a621a965b9e1c4ace08bd0))

* DOC: fix install itself ([`c24b02b`](https://github.com/phim/sravel/snakecdysis/commit/c24b02bca6bd95c2a46c8daa269aab959be1a09f))

* DOC: fix build with readthedocs ([`a96f667`](https://github.com/phim/sravel/snakecdysis/commit/a96f66706b4221d4e29c3e6d17ad3b786ac5e16a))

* fix: profil mem mutually exclusif with mem_per_cpus ([`f7d90c3`](https://github.com/phim/sravel/snakecdysis/commit/f7d90c35bc169b4877241154aee04013bf1b860b))

* fix release version detection ([`b2a864e`](https://github.com/phim/sravel/snakecdysis/commit/b2a864ec54dc9649b8393740d294ab94cc37d057))

* fix release tag regex ([`fe0f79d`](https://github.com/phim/sravel/snakecdysis/commit/fe0f79ddbfcab23c2eef10eb2402f663dfce3492))

* Merge branch &#39;main&#39; of forge.ird.fr:phim/sravel/snakecdysis into main

Conflicts:
	LICENCE ([`69fd9ec`](https://github.com/phim/sravel/snakecdysis/commit/69fd9ec0535f3ebb2328b6d1a8a2a723136bb123))

* untrack build version file ([`ace75fe`](https://github.com/phim/sravel/snakecdysis/commit/ace75fe957b1d9d7876e201930e153f81d847eca))

* add _version.py to git ignore ([`e91a725`](https://github.com/phim/sravel/snakecdysis/commit/e91a72595b9e012a650ae846456927cd163dda6e))

* update licence to MIT ([`1c3242d`](https://github.com/phim/sravel/snakecdysis/commit/1c3242d5a3056b4d1542aaf4166b6400d56c2da5))

* update version to first release ([`7046b89`](https://github.com/phim/sravel/snakecdysis/commit/7046b89bdada0a6539e998c0bc25f0fa038cf93f))

* Change to MIT license ([`519292d`](https://github.com/phim/sravel/snakecdysis/commit/519292db9d8ca6d90ed8dffe33ada7ce61aa1606))

* Delete LICENCE ([`3091d6b`](https://github.com/phim/sravel/snakecdysis/commit/3091d6bbab981545bef29c4d971ae8eb8dbf7ba9))

* add Licence file ([`9edc863`](https://github.com/phim/sravel/snakecdysis/commit/9edc863ae757cf4069077378b6edd84816dbf064))

* add pyproject.toml according to pep ([`715e8b8`](https://github.com/phim/sravel/snakecdysis/commit/715e8b80c3ab32560bdeb7d4ab41021ee0d6b239))

* fix some bug ([`4b8291d`](https://github.com/phim/sravel/snakecdysis/commit/4b8291d9693cfa467f0adab707f223e5302d3afa))

* update doc and args ([`d905375`](https://github.com/phim/sravel/snakecdysis/commit/d9053755ca060b29ddf9bc8d2917ef5f4ac14c89))

* update doc ([`9fd1e80`](https://github.com/phim/sravel/snakecdysis/commit/9fd1e800786a7969bb61aa17bf792b0526d144fe))

* update doc ([`828a718`](https://github.com/phim/sravel/snakecdysis/commit/828a718c5c88e4f1694694a62b73e64aef3b6e5c))

* fix typo ([`858e2eb`](https://github.com/phim/sravel/snakecdysis/commit/858e2ebd687b0ea400317d4dad52ff48050091b2))

* add template creation ([`99ae037`](https://github.com/phim/sravel/snakecdysis/commit/99ae037826115010775a6e32e062328b9f130541))

* test version ([`59b3b5f`](https://github.com/phim/sravel/snakecdysis/commit/59b3b5fae593e786562e28cad9fa19a31d0ebdae))

* test version ([`32ab883`](https://github.com/phim/sravel/snakecdysis/commit/32ab88302d6e03c4d46cc26df24ff89be7f58497))

* test version ([`ff94aa5`](https://github.com/phim/sravel/snakecdysis/commit/ff94aa59840dee39da4bb0857e1b852fdd794651))

* fix title ([`b460db2`](https://github.com/phim/sravel/snakecdysis/commit/b460db2986ed9ebb31ecd558692bbe9a9ce68ec1))

* add short logo ([`8dbe974`](https://github.com/phim/sravel/snakecdysis/commit/8dbe9740bbfeeae4fa793a05a9cfd889ac21667a))

* update to RC ([`85550ba`](https://github.com/phim/sravel/snakecdysis/commit/85550ba8c92118e4e225bd6298833b6b83a112f6))

* fix python-gitlab ([`2000cff`](https://github.com/phim/sravel/snakecdysis/commit/2000cff1e16ff3a323397dfafb3b0e63a741ff88))

* add for doc ([`86727e1`](https://github.com/phim/sravel/snakecdysis/commit/86727e195842cf0ee2c0575c8166a3b4c2251668))

* add for doc ([`9559960`](https://github.com/phim/sravel/snakecdysis/commit/95599602548c33837db7ce9845d8860d6c475913))

* add logo ([`c94a2b8`](https://github.com/phim/sravel/snakecdysis/commit/c94a2b8bffb1ee9c111a401f4a93a03c6eb1f919))

* Rename to Snakecdysis ([`4c83f75`](https://github.com/phim/sravel/snakecdysis/commit/4c83f753cedbe140606094a7852256f7e337946b))

* add .idea ([`76c26e7`](https://github.com/phim/sravel/snakecdysis/commit/76c26e711e764a63999a5897d0f442195c40f2a6))

* update ([`25734cb`](https://github.com/phim/sravel/snakecdysis/commit/25734cb79878fc106e743ce253714b0a48c490d2))

* update ([`f650cff`](https://github.com/phim/sravel/snakecdysis/commit/f650cffb8e54f0b2039e3e4ba4b4f9b764a7c715))

* mv to good directory ([`6ba2f13`](https://github.com/phim/sravel/snakecdysis/commit/6ba2f13b41ffecb7541865aae6d4b7a546b1c272))

* WRITE DOCS AND DOCSTRING ([`28c8e08`](https://github.com/phim/sravel/snakecdysis/commit/28c8e08dd529ce12c3100e186a8e023442c22b69))

* first fonctionnal version of snakewrapper ([`84a5da1`](https://github.com/phim/sravel/snakecdysis/commit/84a5da17d4858a9736bb88b6948b69ae98c01550))

* rm ([`a6d2f96`](https://github.com/phim/sravel/snakecdysis/commit/a6d2f9673158696cce68217df1619d7f1e2866ac))

* initial commit ([`8727d05`](https://github.com/phim/sravel/snakecdysis/commit/8727d05b3ecb19065e9a25122dc8e99832fc1e35))

* Initial commit ([`55392d9`](https://github.com/phim/sravel/snakecdysis/commit/55392d91217f89319414cdfaa0ca181882d35892))
